.. _head_pose.angles:

Head Pose Angles
================

.. automodule:: eyetrace.head_pose.angles
   :members:
   :undoc-members:
   :show-inheritance:

This module implements Perspective-n-Point (PnP) to estimate head pose angles
from facial landmarks provided by MediaPipe Face Mesh. The function
`head_pose_angles` returns pitch, roll, and yaw in radians.